NanoidCharset class abstract

Charset definitions for Nanoid.

Constructors

NanoidCharset()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

alphanumeric → const String
Letters and digits, no symbols (62 characters).
hex → const String
Hexadecimal lowercase (16 characters).
lowercase → const String
Lowercase letters and digits (36 characters).
numeric → const String
Digits only (10 characters).
urlSafe → const String
Standard URL-safe Base64 charset (64 characters). Includes letters, digits, '-' and '_'.
urlSafeHumanFriendly → const String
Human-friendly URL-safe charset. Removes characters that can be confused with others: